-- Compiled by Scene2Res, a MTA:SA GTA III engine map importer
local textureCache = {};
local streamedObjects = {};
local pModels = {};

setCloudsEnabled(false);
debug.sethook(nil);

local function getResourceSize(path)
	if not (fileExists(path)) then return 0; end;

	local file = fileOpen(path);
	local size = fileGetSize(file)

	fileClose(file);
	return size;
end

local function requestTexture(model, path)
	local txd = textureCache[path];

	if not (txd) then
		local size = getResourceSize(path);
		if (size == 0) then return false; end

		txd = engineLoadTXD(path, false);

		if not (txd) then
			return false;
		end

		textureCache[path] = txd;
	end
	return txd;
end

local function loadModel(model)
	if (model.loaded) then return true; end

	if (model.super) then
       local superModel = pModels[model.super];
       if (superModel) then
		    if not (loadModel(superModel)) then
			    return false;
		    end
       end
	end

	engineReplaceModel(model.model, model.id);
	engineReplaceCOL(model.col, model.id);

	model.loaded = true;
	return true;
end

local function freeModel(model)
	if not (model.loaded) then return true; end

	engineRestoreModel(model.id);
	engineRestoreCOL(model.id);

	model.loaded = false;
	if (model.super) then
       local superModel = pModels[model.super];
       if (superModel) then
		    freeModel(superModel);
       end
	end
end

local function modelStreamOut ()
	local pModel = pModels[getElementModel(source)];

	if not (pModel) then return end;

	if (pModel.lodID) then return true; end

	if (pModel.isRequesting == 2) then
		pModel.isRequesting = 1;
		return true;
	elseif (pModel.isRequesting == 3) then
		pModel.isRequesting = 4;
		return true;
	elseif (pModel.isRequesting) then return true; end

	pModel.numStream = pModel.numStream - 1;

	if (pModel.numStream == 0) then
		pModel.isRequesting = 3;

		freeModel(pModel);

		pModel.isRequesting = false;
	end
end

local function modelStreamIn ()
	local pModel = pModels[getElementModel(source)];

	if not (pModel) then return end;

	if (pModel.lodID) then return true; end

	if (pModel.isRequesting == 1) then
		pModel.isRequesting = false;
		return true;
	elseif (pModel.isRequesting) then return true; end

	pModel.numStream = pModel.numStream + 1;

	if not (pModel.numStream == 1) then return true; end

	pModel.isRequesting = 2;

	if not (loadModel(pModel)) then
		setElementInterior(source, 123);
		setElementCollisionsEnabled(source, false);
	end

	if (pModel.isRequesting == 2) then
		outputDebugString("invalid model request '"..pModel.name.."'");
		freeModel(pModel);
		pModel.isRequesting = false;

		pModel.numStream = 0;
	end
end

function loadModels ()
	local pModel, pTXD, pColl, pTable;

	pTable={

	};

	for m,n in ipairs(pTable) do
		pModels[n[1]] = {
			id = n[1],
			name = n[2],
			txd = requestTexture(false, "textures/"..n[3]..".txd"),
			numStream = 0,
			lod = n[4] / 5,
			super = n[5]
		};
		pModelEntry = pModels[n[1]];
		engineImportTXD(pModelEntry.txd, n[1]);
		pModelEntry.model = engineLoadDFF("models/"..n[2]..".dff", n[1]);
		engineReplaceModel(pModelEntry.model, n[1]);
		if ( #n == 6 ) then
			pModelEntry.col = engineLoadCOL("coll/"..n[6]..".col");
			engineReplaceCOL(pModelEntry.col, n[1]);
		end
		engineSetModelLODDistance(n[1], n[4] / 5);
	end

	pTable={
		{ model=3975, model_file="build55", txd_file="main", coll_file="build55", lod=500 },
		{ model=3976, model_file="build54", txd_file="main", coll_file="build54", lod=500 },
		{ model=3977, model_file="build53", txd_file="main", coll_file="build53", lod=500 },
		{ model=3978, model_file="build60", txd_file="main", coll_file="build60", lod=500 },
		{ model=3979, model_file="build389", txd_file="main", coll_file="build389", lod=500 },
		{ model=3980, model_file="build388", txd_file="main", coll_file="build388", lod=500 },
		{ model=3981, model_file="build438", txd_file="main", coll_file="build438", lod=500 },
		{ model=3982, model_file="build444", txd_file="main", coll_file="build444", lod=500 },
		{ model=3983, model_file="build445", txd_file="main", coll_file="build445", lod=500 },
		{ model=3984, model_file="build447", txd_file="main", coll_file="build447", lod=500 },
		{ model=3985, model_file="build63", txd_file="main", coll_file="build63", lod=500 },
		{ model=3986, model_file="build435", txd_file="main", coll_file="build435", lod=500 },
		{ model=3987, model_file="build64", txd_file="main", coll_file="build64", lod=500 },
		{ model=3988, model_file="build456", txd_file="main", coll_file="build456", lod=500 },
		{ model=3989, model_file="build65", txd_file="main", coll_file="build65", lod=500 },
		{ model=3990, model_file="build459", txd_file="main", coll_file="build459", lod=500 },
		{ model=3993, model_file="build386", txd_file="main", coll_file="build386", lod=500 },
		{ model=3994, model_file="build385", txd_file="main", coll_file="build385", lod=500 },
		{ model=3995, model_file="build382", txd_file="main", coll_file="build382", lod=500 },
		{ model=3996, model_file="build02", txd_file="main", coll_file="build02", lod=500 },
		{ model=3997, model_file="build384", txd_file="main", coll_file="build384", lod=500 },
		{ model=3998, model_file="build04", txd_file="main", coll_file="build04", lod=500 },
		{ model=3999, model_file="build387", txd_file="main", coll_file="build387", lod=500 },
		{ model=4000, model_file="build383", txd_file="main", coll_file="build383", lod=500 },
		{ model=4001, model_file="build03", txd_file="main", coll_file="build03", lod=500 },
		{ model=4002, model_file="build08", txd_file="main", coll_file="build08", lod=500 },
		{ model=4004, model_file="build62", txd_file="main", coll_file="build62", lod=500 },
		{ model=4005, model_file="build09", txd_file="main", coll_file="build09", lod=500 },
		{ model=4006, model_file="build11", txd_file="main", coll_file="build11", lod=500 },
		{ model=4007, model_file="build437", txd_file="main", coll_file="build437", lod=500 },
		{ model=4008, model_file="build436", txd_file="main", coll_file="build436", lod=500 },
		{ model=4009, model_file="build10", txd_file="main", coll_file="build10", lod=500 },
		{ model=4010, model_file="build443", txd_file="main", coll_file="build443", lod=500 },
		{ model=4011, model_file="build440", txd_file="main", coll_file="build440", lod=500 },
		{ model=4012, model_file="build441", txd_file="main", coll_file="build441", lod=500 },
		{ model=4013, model_file="build448", txd_file="main", coll_file="build448", lod=500 },
		{ model=4014, model_file="build450", txd_file="main", coll_file="build450", lod=500 },
		{ model=4016, model_file="build451", txd_file="main", coll_file="build451", lod=500 },
		{ model=4017, model_file="build449", txd_file="main", coll_file="build449", lod=500 },
		{ model=4018, model_file="build452", txd_file="main", coll_file="build452", lod=500 },
		{ model=4019, model_file="build12", txd_file="main", coll_file="build12", lod=500 },
		{ model=4021, model_file="build457", txd_file="main", coll_file="build457", lod=500 },
		{ model=4022, model_file="build458", txd_file="main", coll_file="build458", lod=500 },
		{ model=4023, model_file="build01", txd_file="main", coll_file="build01", lod=500 },
		{ model=4024, model_file="build442", txd_file="main", coll_file="build442", lod=500 },
		{ model=4025, model_file="build14", txd_file="main", coll_file="build14", lod=500 },
		{ model=4026, model_file="build15", txd_file="main", coll_file="build15", lod=500 },
		{ model=4027, model_file="build381", txd_file="main", coll_file="build381", lod=500 },
		{ model=4028, model_file="build392", txd_file="main", coll_file="build392", lod=500 },
		{ model=4029, model_file="build396", txd_file="main", coll_file="build396", lod=500 },
		{ model=4030, model_file="build397", txd_file="main", coll_file="build397", lod=500 },
		{ model=4031, model_file="build434", txd_file="main", coll_file="build434", lod=500 },
		{ model=4032, model_file="build400", txd_file="main", coll_file="build400", lod=500 },
		{ model=4033, model_file="build399", txd_file="main", coll_file="build399", lod=500 },
		{ model=4035, model_file="build398", txd_file="main", coll_file="build398", lod=500 },
		{ model=4036, model_file="build401", txd_file="main", coll_file="build401", lod=500 },
		{ model=4037, model_file="build61", txd_file="main", coll_file="build61", lod=500 },
		{ model=4038, model_file="build391", txd_file="main", coll_file="build391", lod=500 },
		{ model=4039, model_file="build402", txd_file="main", coll_file="build402", lod=500 },
		{ model=4040, model_file="build446", txd_file="main", coll_file="build446", lod=500 },
		{ model=4041, model_file="build406", txd_file="main", coll_file="build406", lod=500 },
		{ model=4042, model_file="build455", txd_file="main", coll_file="build455", lod=500 },
		{ model=4043, model_file="build454", txd_file="main", coll_file="build454", lod=500 },
		{ model=4044, model_file="build412", txd_file="main", coll_file="build412", lod=500 },
		{ model=4045, model_file="build413", txd_file="main", coll_file="build413", lod=500 },
		{ model=4046, model_file="build411", txd_file="main", coll_file="build411", lod=500 },
		{ model=4047, model_file="build408", txd_file="main", coll_file="build408", lod=500 },
		{ model=4048, model_file="build414", txd_file="main", coll_file="build414", lod=500 },
		{ model=4049, model_file="build409", txd_file="main", coll_file="build409", lod=500 },
		{ model=4050, model_file="build410", txd_file="main", coll_file="build410", lod=500 },
		{ model=4051, model_file="build407", txd_file="main", coll_file="build407", lod=500 },
		{ model=4052, model_file="build403", txd_file="main", coll_file="build403", lod=500 },
		{ model=4053, model_file="build415", txd_file="main", coll_file="build415", lod=500 },
		{ model=4054, model_file="build395", txd_file="main", coll_file="build395", lod=500 },
		{ model=4055, model_file="build393", txd_file="main", coll_file="build393", lod=500 },
		{ model=4056, model_file="build422", txd_file="main", coll_file="build422", lod=500 },
		{ model=4057, model_file="build418", txd_file="main", coll_file="build418", lod=500 },
		{ model=4058, model_file="build421", txd_file="main", coll_file="build421", lod=500 },
		{ model=4059, model_file="build424", txd_file="main", coll_file="build424", lod=500 },
		{ model=4060, model_file="build419", txd_file="main", coll_file="build419", lod=500 },
		{ model=4061, model_file="build416", txd_file="main", coll_file="build416", lod=500 },
		{ model=4062, model_file="build423", txd_file="main", coll_file="build423", lod=500 },
		{ model=4063, model_file="build420", txd_file="main", coll_file="build420", lod=500 },
		{ model=4064, model_file="build417", txd_file="main", coll_file="build417", lod=500 },
		{ model=4065, model_file="build405", txd_file="main", coll_file="build405", lod=500 },
		{ model=4066, model_file="build428", txd_file="main", coll_file="build428", lod=500 },
		{ model=4067, model_file="build429", txd_file="main", coll_file="build429", lod=500 },
		{ model=4068, model_file="build431", txd_file="main", coll_file="build431", lod=500 },
		{ model=4069, model_file="build430", txd_file="main", coll_file="build430", lod=500 },
		{ model=4070, model_file="build427", txd_file="main", coll_file="build427", lod=500 },
		{ model=4071, model_file="build426", txd_file="main", coll_file="build426", lod=500 },
		{ model=4072, model_file="build404", txd_file="main", coll_file="build404", lod=500 },
		{ model=4073, model_file="build425", txd_file="main", coll_file="build425", lod=500 },
		{ model=4074, model_file="build432", txd_file="main", coll_file="build432", lod=500 },
		{ model=4075, model_file="build433", txd_file="main", coll_file="build433", lod=500 },
		{ model=4076, model_file="build394", txd_file="main", coll_file="build394", lod=500 },
		{ model=4077, model_file="build390", txd_file="main", coll_file="build390", lod=500 },
		{ model=4078, model_file="build453", txd_file="main", coll_file="build453", lod=500 },
		{ model=4079, model_file="build07", txd_file="main", coll_file="build07", lod=500 },
		{ model=4080, model_file="build05", txd_file="main", coll_file="build05", lod=500 },
		{ model=4081, model_file="build06", txd_file="main", coll_file="build06", lod=500 },
		{ model=4082, model_file="build13", txd_file="main", coll_file="build13", lod=500 },
		{ model=4083, model_file="build380", txd_file="main", coll_file="build380", lod=500 },
		{ model=4085, model_file="build379", txd_file="main", coll_file="build379", lod=500 },
		{ model=4086, model_file="build378", txd_file="main", coll_file="build378", lod=500 },
		{ model=4087, model_file="build377", txd_file="main", coll_file="build377", lod=500 },
		{ model=4088, model_file="build376", txd_file="main", coll_file="build376", lod=500 },
		{ model=4089, model_file="build375", txd_file="main", coll_file="build375", lod=500 },
		{ model=4090, model_file="build374", txd_file="main", coll_file="build374", lod=500 },
		{ model=4091, model_file="build373", txd_file="main", coll_file="build373", lod=500 },
		{ model=4092, model_file="build372", txd_file="main", coll_file="build372", lod=500 },
		{ model=4093, model_file="build371", txd_file="main", coll_file="build371", lod=500 },
		{ model=4094, model_file="build370", txd_file="main", coll_file="build370", lod=500 },
		{ model=4095, model_file="build369", txd_file="main", coll_file="build369", lod=500 },
		{ model=4096, model_file="build368", txd_file="main", coll_file="build368", lod=500 },
		{ model=4097, model_file="build367", txd_file="main", coll_file="build367", lod=500 },
		{ model=4098, model_file="build366", txd_file="main", coll_file="build366", lod=500 },
		{ model=4101, model_file="build365", txd_file="main", coll_file="build365", lod=500 },
		{ model=4103, model_file="build364", txd_file="main", coll_file="build364", lod=500 },
		{ model=4104, model_file="build363", txd_file="main", coll_file="build363", lod=500 },
		{ model=4105, model_file="build362", txd_file="main", coll_file="build362", lod=500 },
		{ model=4108, model_file="build361", txd_file="main", coll_file="build361", lod=500 },
		{ model=4109, model_file="build360", txd_file="main", coll_file="build360", lod=500 },
		{ model=4110, model_file="build359", txd_file="main", coll_file="build359", lod=500 },
		{ model=4111, model_file="build358", txd_file="main", coll_file="build358", lod=500 },
		{ model=4112, model_file="build357", txd_file="main", coll_file="build357", lod=500 },
		{ model=4113, model_file="build356", txd_file="main", coll_file="build356", lod=500 },
		{ model=4114, model_file="build355", txd_file="main", coll_file="build355", lod=500 },
		{ model=4115, model_file="build354", txd_file="main", coll_file="build354", lod=500 },
		{ model=4116, model_file="build353", txd_file="main", coll_file="build353", lod=500 },
		{ model=4117, model_file="build352", txd_file="main", coll_file="build352", lod=500 },
		{ model=4118, model_file="build351", txd_file="main", coll_file="build351", lod=500 },
		{ model=4119, model_file="build350", txd_file="main", coll_file="build350", lod=500 },
		{ model=4122, model_file="build349", txd_file="main", coll_file="build349", lod=500 },
		{ model=4123, model_file="build348", txd_file="main", coll_file="build348", lod=500 },
		{ model=4124, model_file="build347", txd_file="main", coll_file="build347", lod=500 },
		{ model=4125, model_file="build346", txd_file="main", coll_file="build346", lod=500 },
		{ model=4126, model_file="build345", txd_file="main", coll_file="build345", lod=500 },
		{ model=4127, model_file="build344", txd_file="main", coll_file="build344", lod=500 },
		{ model=4128, model_file="build343", txd_file="main", coll_file="build343", lod=500 },
		{ model=4130, model_file="build342", txd_file="main", coll_file="build342", lod=500 },
		{ model=4132, model_file="build341", txd_file="main", coll_file="build341", lod=500 },
		{ model=4133, model_file="build340", txd_file="main", coll_file="build340", lod=500 },
		{ model=4134, model_file="build339", txd_file="main", coll_file="build339", lod=500 },
		{ model=4135, model_file="build338", txd_file="main", coll_file="build338", lod=500 },
		{ model=4136, model_file="build337", txd_file="main", coll_file="build337", lod=500 },
		{ model=4137, model_file="build336", txd_file="main", coll_file="build336", lod=500 },
		{ model=4138, model_file="build335", txd_file="main", coll_file="build335", lod=500 },
		{ model=4139, model_file="build334", txd_file="main", coll_file="build334", lod=500 },
		{ model=4140, model_file="build333", txd_file="main", coll_file="build333", lod=500 },
		{ model=4141, model_file="build332", txd_file="main", coll_file="build332", lod=500 },
		{ model=4142, model_file="build331", txd_file="main", coll_file="build331", lod=500 },
		{ model=4143, model_file="build330", txd_file="main", coll_file="build330", lod=500 },
		{ model=4144, model_file="build329", txd_file="main", coll_file="build329", lod=500 },
		{ model=4145, model_file="build328", txd_file="main", coll_file="build328", lod=500 },
		{ model=4146, model_file="build327", txd_file="main", coll_file="build327", lod=500 },
		{ model=4147, model_file="build326", txd_file="main", coll_file="build326", lod=500 },
		{ model=4148, model_file="build325", txd_file="main", coll_file="build325", lod=500 },
		{ model=4149, model_file="build324", txd_file="main", coll_file="build324", lod=500 },
		{ model=4150, model_file="build323", txd_file="main", coll_file="build323", lod=500 },
		{ model=4151, model_file="build322", txd_file="main", coll_file="build322", lod=500 },
		{ model=4152, model_file="build321", txd_file="main", coll_file="build321", lod=500 },
		{ model=4153, model_file="build320", txd_file="main", coll_file="build320", lod=500 },
		{ model=4154, model_file="build319", txd_file="main", coll_file="build319", lod=500 },
		{ model=4155, model_file="build318", txd_file="main", coll_file="build318", lod=500 },
		{ model=4157, model_file="build317", txd_file="main", coll_file="build317", lod=500 },
		{ model=4158, model_file="build316", txd_file="main", coll_file="build316", lod=500 },
		{ model=4159, model_file="build315", txd_file="main", coll_file="build315", lod=500 },
		{ model=4160, model_file="build314", txd_file="main", coll_file="build314", lod=500 },
		{ model=4161, model_file="build313", txd_file="main", coll_file="build313", lod=500 },
		{ model=4162, model_file="build312", txd_file="main", coll_file="build312", lod=500 },
		{ model=4164, model_file="build311", txd_file="main", coll_file="build311", lod=500 },
		{ model=4166, model_file="build310", txd_file="main", coll_file="build310", lod=500 },
		{ model=4167, model_file="build309", txd_file="main", coll_file="build309", lod=500 },
		{ model=4169, model_file="build308", txd_file="main", coll_file="build308", lod=500 },
		{ model=4176, model_file="build307", txd_file="main", coll_file="build307", lod=500 },
		{ model=4177, model_file="build306", txd_file="main", coll_file="build306", lod=500 },
		{ model=4178, model_file="build305", txd_file="main", coll_file="build305", lod=500 },
		{ model=4179, model_file="build304", txd_file="main", coll_file="build304", lod=500 },
		{ model=4181, model_file="build303", txd_file="main", coll_file="build303", lod=500 },
		{ model=4182, model_file="build302", txd_file="main", coll_file="build302", lod=500 },
		{ model=4186, model_file="build301", txd_file="main", coll_file="build301", lod=500 },
		{ model=4187, model_file="build300", txd_file="main", coll_file="build300", lod=500 },
		{ model=4188, model_file="build299", txd_file="main", coll_file="build299", lod=500 },
		{ model=4191, model_file="build298", txd_file="main", coll_file="build298", lod=500 },
		{ model=4193, model_file="build297", txd_file="main", coll_file="build297", lod=500 },
		{ model=4194, model_file="build296", txd_file="main", coll_file="build296", lod=500 },
		{ model=4197, model_file="build295", txd_file="main", coll_file="build295", lod=500 },
		{ model=4198, model_file="build294", txd_file="main", coll_file="build294", lod=500 },
		{ model=4199, model_file="build293", txd_file="main", coll_file="build293", lod=500 },
		{ model=4200, model_file="build292", txd_file="main", coll_file="build292", lod=500 },
		{ model=4203, model_file="build291", txd_file="main", coll_file="build291", lod=500 },
		{ model=4204, model_file="build290", txd_file="main", coll_file="build290", lod=500 },
		{ model=4208, model_file="build289", txd_file="main", coll_file="build289", lod=500 },
		{ model=4209, model_file="build288", txd_file="main", coll_file="build288", lod=500 },
		{ model=4210, model_file="build287", txd_file="main", coll_file="build287", lod=500 },
		{ model=4211, model_file="build286", txd_file="main", coll_file="build286", lod=500 },
		{ model=4223, model_file="build285", txd_file="main", coll_file="build285", lod=500 },
		{ model=4224, model_file="build284", txd_file="main", coll_file="build284", lod=500 },
		{ model=4225, model_file="build283", txd_file="main", coll_file="build283", lod=500 },
		{ model=4226, model_file="build282", txd_file="main", coll_file="build282", lod=500 },
		{ model=4228, model_file="build281", txd_file="main", coll_file="build281", lod=500 },
		{ model=4229, model_file="build280", txd_file="main", coll_file="build280", lod=500 },
		{ model=4232, model_file="build279", txd_file="main", coll_file="build279", lod=500 },
		{ model=4234, model_file="build278", txd_file="main", coll_file="build278", lod=500 },
		{ model=4235, model_file="build277", txd_file="main", coll_file="build277", lod=500 },
		{ model=4236, model_file="build276", txd_file="main", coll_file="build276", lod=500 },
		{ model=4237, model_file="build275", txd_file="main", coll_file="build275", lod=500 },
		{ model=4238, model_file="build274", txd_file="main", coll_file="build274", lod=500 },
		{ model=4239, model_file="build273", txd_file="main", coll_file="build273", lod=500 },
		{ model=4347, model_file="build272", txd_file="main", coll_file="build272", lod=500 },
		{ model=4375, model_file="build271", txd_file="main", coll_file="build271", lod=500 },
		{ model=4376, model_file="build270", txd_file="main", coll_file="build270", lod=500 },
		{ model=4377, model_file="build269", txd_file="main", coll_file="build269", lod=500 },
		{ model=4378, model_file="build268", txd_file="main", coll_file="build268", lod=500 },
		{ model=4379, model_file="build267", txd_file="main", coll_file="build267", lod=500 },
		{ model=4380, model_file="build266", txd_file="main", coll_file="build266", lod=500 },
		{ model=4381, model_file="build265", txd_file="main", coll_file="build265", lod=500 },
		{ model=4382, model_file="build264", txd_file="main", coll_file="build264", lod=500 },
		{ model=4383, model_file="build263", txd_file="main", coll_file="build263", lod=500 },
		{ model=4384, model_file="build262", txd_file="main", coll_file="build262", lod=500 },
		{ model=4385, model_file="build261", txd_file="main", coll_file="build261", lod=500 },
		{ model=4386, model_file="build260", txd_file="main", coll_file="build260", lod=500 },
		{ model=4387, model_file="build259", txd_file="main", coll_file="build259", lod=500 },
		{ model=4388, model_file="build258", txd_file="main", coll_file="build258", lod=500 },
		{ model=4389, model_file="build257", txd_file="main", coll_file="build257", lod=500 },
		{ model=4390, model_file="build256", txd_file="main", coll_file="build256", lod=500 },
		{ model=4391, model_file="build255", txd_file="main", coll_file="build255", lod=500 },
		{ model=4392, model_file="build254", txd_file="main", coll_file="build254", lod=500 },
		{ model=4393, model_file="build253", txd_file="main", coll_file="build253", lod=500 },
		{ model=4394, model_file="build252", txd_file="main", coll_file="build252", lod=500 },
		{ model=4395, model_file="build251", txd_file="main", coll_file="build251", lod=500 },
		{ model=4396, model_file="build250", txd_file="main", coll_file="build250", lod=500 },
		{ model=4397, model_file="build249", txd_file="main", coll_file="build249", lod=500 },
		{ model=4398, model_file="build248", txd_file="main", coll_file="build248", lod=500 },
		{ model=4399, model_file="build247", txd_file="main", coll_file="build247", lod=500 },
		{ model=4400, model_file="build246", txd_file="main", coll_file="build246", lod=500 },
		{ model=4401, model_file="build245", txd_file="main", coll_file="build245", lod=500 },
		{ model=4402, model_file="build244", txd_file="main", coll_file="build244", lod=500 },
		{ model=4403, model_file="build243", txd_file="main", coll_file="build243", lod=500 },
		{ model=4404, model_file="build242", txd_file="main", coll_file="build242", lod=500 },
		{ model=4405, model_file="build241", txd_file="main", coll_file="build241", lod=500 },
		{ model=4406, model_file="build240", txd_file="main", coll_file="build240", lod=500 },
		{ model=4407, model_file="build239", txd_file="main", coll_file="build239", lod=500 },
		{ model=4408, model_file="build238", txd_file="main", coll_file="build238", lod=500 },
		{ model=4409, model_file="build237", txd_file="main", coll_file="build237", lod=500 },
		{ model=4410, model_file="build236", txd_file="main", coll_file="build236", lod=500 },
		{ model=4411, model_file="build235", txd_file="main", coll_file="build235", lod=500 },
		{ model=4412, model_file="build234", txd_file="main", coll_file="build234", lod=500 },
		{ model=4413, model_file="build233", txd_file="main", coll_file="build233", lod=500 },
		{ model=4414, model_file="build232", txd_file="main", coll_file="build232", lod=500 },
		{ model=4415, model_file="build231", txd_file="main", coll_file="build231", lod=500 },
		{ model=4416, model_file="build230", txd_file="main", coll_file="build230", lod=500 },
		{ model=4417, model_file="build229", txd_file="main", coll_file="build229", lod=500 },
		{ model=4418, model_file="build228", txd_file="main", coll_file="build228", lod=500 },
		{ model=4419, model_file="build227", txd_file="main", coll_file="build227", lod=500 },
		{ model=4420, model_file="build226", txd_file="main", coll_file="build226", lod=500 },
		{ model=4421, model_file="build225", txd_file="main", coll_file="build225", lod=500 },
		{ model=4422, model_file="build224", txd_file="main", coll_file="build224", lod=500 },
		{ model=4423, model_file="build223", txd_file="main", coll_file="build223", lod=500 },
		{ model=4424, model_file="build222", txd_file="main", coll_file="build222", lod=500 },
		{ model=4425, model_file="build221", txd_file="main", coll_file="build221", lod=500 },
		{ model=4426, model_file="build220", txd_file="main", coll_file="build220", lod=500 },
		{ model=4427, model_file="build219", txd_file="main", coll_file="build219", lod=500 },
		{ model=4428, model_file="build218", txd_file="main", coll_file="build218", lod=500 },
		{ model=4429, model_file="build217", txd_file="main", coll_file="build217", lod=500 },
		{ model=4430, model_file="build216", txd_file="main", coll_file="build216", lod=500 },
		{ model=4431, model_file="build215", txd_file="main", coll_file="build215", lod=500 },
		{ model=4432, model_file="build214", txd_file="main", coll_file="build214", lod=500 },
		{ model=4433, model_file="build213", txd_file="main", coll_file="build213", lod=500 },
		{ model=4434, model_file="build212", txd_file="main", coll_file="build212", lod=500 },
		{ model=4435, model_file="build211", txd_file="main", coll_file="build211", lod=500 },
		{ model=4436, model_file="build210", txd_file="main", coll_file="build210", lod=500 },
		{ model=4437, model_file="build209", txd_file="main", coll_file="build209", lod=500 },
		{ model=4438, model_file="build208", txd_file="main", coll_file="build208", lod=500 },
		{ model=4439, model_file="build207", txd_file="main", coll_file="build207", lod=500 },
		{ model=4440, model_file="build206", txd_file="main", coll_file="build206", lod=500 },
		{ model=4441, model_file="build205", txd_file="main", coll_file="build205", lod=500 },
		{ model=4442, model_file="build204", txd_file="main", coll_file="build204", lod=500 },
		{ model=4443, model_file="build203", txd_file="main", coll_file="build203", lod=500 },
		{ model=4444, model_file="build202", txd_file="main", coll_file="build202", lod=500 },
		{ model=4445, model_file="build201", txd_file="main", coll_file="build201", lod=500 },
		{ model=4446, model_file="build200", txd_file="main", coll_file="build200", lod=500 },
		{ model=4447, model_file="build199", txd_file="main", coll_file="build199", lod=500 },
		{ model=4448, model_file="build198", txd_file="main", coll_file="build198", lod=500 },
		{ model=4449, model_file="build197", txd_file="main", coll_file="build197", lod=500 },
		{ model=4450, model_file="build196", txd_file="main", coll_file="build196", lod=500 },
		{ model=4451, model_file="build195", txd_file="main", coll_file="build195", lod=500 },
		{ model=4452, model_file="build194", txd_file="main", coll_file="build194", lod=500 },
		{ model=4453, model_file="build193", txd_file="main", coll_file="build193", lod=500 },
		{ model=4454, model_file="build192", txd_file="main", coll_file="build192", lod=500 },
		{ model=4455, model_file="build191", txd_file="main", coll_file="build191", lod=500 },
		{ model=4456, model_file="build190", txd_file="main", coll_file="build190", lod=500 },
		{ model=4457, model_file="build189", txd_file="main", coll_file="build189", lod=500 },
		{ model=4458, model_file="build188", txd_file="main", coll_file="build188", lod=500 },
		{ model=4459, model_file="build187", txd_file="main", coll_file="build187", lod=500 },
		{ model=4460, model_file="build186", txd_file="main", coll_file="build186", lod=500 },
		{ model=4461, model_file="build185", txd_file="main", coll_file="build185", lod=500 },
		{ model=4462, model_file="build184", txd_file="main", coll_file="build184", lod=500 },
		{ model=4463, model_file="build183", txd_file="main", coll_file="build183", lod=500 },
		{ model=4464, model_file="build182", txd_file="main", coll_file="build182", lod=500 },
		{ model=4465, model_file="build181", txd_file="main", coll_file="build181", lod=500 },
		{ model=4466, model_file="build180", txd_file="main", coll_file="build180", lod=500 },
		{ model=4467, model_file="build179", txd_file="main", coll_file="build179", lod=500 },
		{ model=4468, model_file="build178", txd_file="main", coll_file="build178", lod=500 },
		{ model=4469, model_file="build177", txd_file="main", coll_file="build177", lod=500 },
		{ model=4470, model_file="build176", txd_file="main", coll_file="build176", lod=500 },
		{ model=4471, model_file="build175", txd_file="main", coll_file="build175", lod=500 },
		{ model=4472, model_file="build174", txd_file="main", coll_file="build174", lod=500 },
		{ model=4473, model_file="build173", txd_file="main", coll_file="build173", lod=500 },
		{ model=4474, model_file="build172", txd_file="main", coll_file="build172", lod=500 },
		{ model=4475, model_file="build171", txd_file="main", coll_file="build171", lod=500 },
		{ model=4476, model_file="build170", txd_file="main", coll_file="build170", lod=500 },
		{ model=4477, model_file="build169", txd_file="main", coll_file="build169", lod=500 },
		{ model=4478, model_file="build168", txd_file="main", coll_file="build168", lod=500 },
		{ model=4479, model_file="build167", txd_file="main", coll_file="build167", lod=500 },
		{ model=4480, model_file="build166", txd_file="main", coll_file="build166", lod=500 },
		{ model=4481, model_file="build165", txd_file="main", coll_file="build165", lod=500 },
		{ model=4482, model_file="build164", txd_file="main", coll_file="build164", lod=500 },
		{ model=4483, model_file="build163", txd_file="main", coll_file="build163", lod=500 },
		{ model=4484, model_file="build162", txd_file="main", coll_file="build162", lod=500 },
		{ model=4485, model_file="build161", txd_file="main", coll_file="build161", lod=500 },
		{ model=4486, model_file="build160", txd_file="main", coll_file="build160", lod=500 },
		{ model=4487, model_file="build159", txd_file="main", coll_file="build159", lod=500 },
		{ model=4488, model_file="build158", txd_file="main", coll_file="build158", lod=500 },
		{ model=4489, model_file="build157", txd_file="main", coll_file="build157", lod=500 },
		{ model=4490, model_file="build156", txd_file="main", coll_file="build156", lod=500 },
		{ model=4491, model_file="build155", txd_file="main", coll_file="build155", lod=500 },
		{ model=4492, model_file="build154", txd_file="main", coll_file="build154", lod=500 },
		{ model=4493, model_file="build153", txd_file="main", coll_file="build153", lod=500 },
		{ model=4494, model_file="build152", txd_file="main", coll_file="build152", lod=500 },
		{ model=4495, model_file="build151", txd_file="main", coll_file="build151", lod=500 },
		{ model=4496, model_file="build150", txd_file="main", coll_file="build150", lod=500 },
		{ model=4497, model_file="build149", txd_file="main", coll_file="build149", lod=500 },
		{ model=4498, model_file="build148", txd_file="main", coll_file="build148", lod=500 },
		{ model=4499, model_file="build147", txd_file="main", coll_file="build147", lod=500 },
		{ model=4500, model_file="build146", txd_file="main", coll_file="build146", lod=500 },
		{ model=4501, model_file="build145", txd_file="main", coll_file="build145", lod=500 },
		{ model=4502, model_file="build144", txd_file="main", coll_file="build144", lod=500 },
		{ model=4503, model_file="build143", txd_file="main", coll_file="build143", lod=500 },
		{ model=4504, model_file="build142", txd_file="main", coll_file="build142", lod=500 },
		{ model=4505, model_file="build141", txd_file="main", coll_file="build141", lod=500 },
		{ model=4506, model_file="build140", txd_file="main", coll_file="build140", lod=500 },
		{ model=4507, model_file="build139", txd_file="main", coll_file="build139", lod=500 },
		{ model=4508, model_file="build138", txd_file="main", coll_file="build138", lod=500 },
		{ model=4509, model_file="build137", txd_file="main", coll_file="build137", lod=500 },
		{ model=4510, model_file="build136", txd_file="main", coll_file="build136", lod=500 },
		{ model=4511, model_file="build135", txd_file="main", coll_file="build135", lod=500 },
		{ model=4512, model_file="build134", txd_file="main", coll_file="build134", lod=500 },
		{ model=4513, model_file="build133", txd_file="main", coll_file="build133", lod=500 },
		{ model=4514, model_file="build132", txd_file="main", coll_file="build132", lod=500 },
		{ model=4515, model_file="build131", txd_file="main", coll_file="build131", lod=500 },
		{ model=4516, model_file="build130", txd_file="main", coll_file="build130", lod=500 },
		{ model=4517, model_file="build129", txd_file="main", coll_file="build129", lod=500 },
		{ model=4518, model_file="build128", txd_file="main", coll_file="build128", lod=500 },
		{ model=4519, model_file="build127", txd_file="main", coll_file="build127", lod=500 },
		{ model=4520, model_file="build126", txd_file="main", coll_file="build126", lod=500 },
		{ model=4521, model_file="build125", txd_file="main", coll_file="build125", lod=500 },
		{ model=4522, model_file="build124", txd_file="main", coll_file="build124", lod=500 },
		{ model=4523, model_file="build123", txd_file="main", coll_file="build123", lod=500 },
		{ model=4524, model_file="build122", txd_file="main", coll_file="build122", lod=500 },
		{ model=4525, model_file="build121", txd_file="main", coll_file="build121", lod=500 },
		{ model=4526, model_file="build120", txd_file="main", coll_file="build120", lod=500 },
		{ model=4527, model_file="build119", txd_file="main", coll_file="build119", lod=500 },
		{ model=4528, model_file="build118", txd_file="main", coll_file="build118", lod=500 },
		{ model=4529, model_file="build117", txd_file="main", coll_file="build117", lod=500 },
		{ model=4530, model_file="build116", txd_file="main", coll_file="build116", lod=500 },
		{ model=4531, model_file="build115", txd_file="main", coll_file="build115", lod=500 },
		{ model=4532, model_file="build114", txd_file="main", coll_file="build114", lod=500 },
		{ model=4534, model_file="build113", txd_file="main", coll_file="build113", lod=500 },
		{ model=4536, model_file="build112", txd_file="main", coll_file="build112", lod=500 },
		{ model=4537, model_file="build111", txd_file="main", coll_file="build111", lod=500 },
		{ model=4539, model_file="build110", txd_file="main", coll_file="build110", lod=500 },
		{ model=4541, model_file="build109", txd_file="main", coll_file="build109", lod=500 },
		{ model=4551, model_file="build108", txd_file="main", coll_file="build108", lod=500 },
		{ model=4552, model_file="build107", txd_file="main", coll_file="build107", lod=500 },
		{ model=4553, model_file="build106", txd_file="main", coll_file="build106", lod=500 },
		{ model=4554, model_file="build105", txd_file="main", coll_file="build105", lod=500 },
		{ model=4555, model_file="build104", txd_file="main", coll_file="build104", lod=500 },
		{ model=4556, model_file="build103", txd_file="main", coll_file="build103", lod=500 },
		{ model=4557, model_file="build102", txd_file="main", coll_file="build102", lod=500 },
		{ model=4558, model_file="build101", txd_file="main", coll_file="build101", lod=500 },
		{ model=4559, model_file="build100", txd_file="main", coll_file="build100", lod=500 },
		{ model=4560, model_file="build99", txd_file="main", coll_file="build99", lod=500 },
		{ model=4561, model_file="build98", txd_file="main", coll_file="build98", lod=500 },
		{ model=4562, model_file="build97", txd_file="main", coll_file="build97", lod=500 },
		{ model=4564, model_file="build96", txd_file="main", coll_file="build96", lod=500 },
		{ model=4565, model_file="build95", txd_file="main", coll_file="build95", lod=500 },
		{ model=4566, model_file="build94", txd_file="main", coll_file="build94", lod=500 },
		{ model=4567, model_file="build93", txd_file="main", coll_file="build93", lod=500 },
		{ model=4568, model_file="build92", txd_file="main", coll_file="build92", lod=500 },
		{ model=4569, model_file="build91", txd_file="main", coll_file="build91", lod=500 },
		{ model=4570, model_file="build90", txd_file="main", coll_file="build90", lod=500 },
		{ model=4571, model_file="build89", txd_file="main", coll_file="build89", lod=500 },
		{ model=4572, model_file="build88", txd_file="main", coll_file="build88", lod=500 },
		{ model=4573, model_file="build87", txd_file="main", coll_file="build87", lod=500 },
		{ model=4574, model_file="build86", txd_file="main", coll_file="build86", lod=500 },
		{ model=4576, model_file="build85", txd_file="main", coll_file="build85", lod=500 },
		{ model=4577, model_file="build84", txd_file="main", coll_file="build84", lod=500 },
		{ model=4578, model_file="build83", txd_file="main", coll_file="build83", lod=500 },
		{ model=4579, model_file="build82", txd_file="main", coll_file="build82", lod=500 },
		{ model=4580, model_file="build81", txd_file="main", coll_file="build81", lod=500 },
		{ model=4581, model_file="build80", txd_file="main", coll_file="build80", lod=500 },
		{ model=4582, model_file="build79", txd_file="main", coll_file="build79", lod=500 },
		{ model=4583, model_file="build78", txd_file="main", coll_file="build78", lod=500 },
		{ model=4584, model_file="build77", txd_file="main", coll_file="build77", lod=500 },
		{ model=4586, model_file="build76", txd_file="main", coll_file="build76", lod=500 },
		{ model=4587, model_file="build75", txd_file="main", coll_file="build75", lod=500 },
		{ model=4588, model_file="build74", txd_file="main", coll_file="build74", lod=500 },
		{ model=4589, model_file="build73", txd_file="main", coll_file="build73", lod=500 },
		{ model=4590, model_file="build72", txd_file="main", coll_file="build72", lod=500 },
		{ model=4591, model_file="build71", txd_file="main", coll_file="build71", lod=500 },
		{ model=4592, model_file="build70", txd_file="main", coll_file="build70", lod=500 },
		{ model=4593, model_file="build69", txd_file="main", coll_file="build69", lod=500 },
		{ model=4594, model_file="build68", txd_file="main", coll_file="build68", lod=500 },
		{ model=4595, model_file="build67", txd_file="main", coll_file="build67", lod=500 },
		{ model=4597, model_file="build66", txd_file="main", coll_file="build66", lod=500 },
		{ model=4598, model_file="other52", txd_file="main", coll_file="other52", lod=500 },
		{ model=4600, model_file="other50", txd_file="main", coll_file="other50", lod=500 },
		{ model=4601, model_file="other49", txd_file="main", coll_file="other49", lod=500 },
		{ model=4602, model_file="other47", txd_file="main", coll_file="other47", lod=500 },
		{ model=4603, model_file="other45", txd_file="main", coll_file="other45", lod=500 },
		{ model=4604, model_file="other43", txd_file="main", coll_file="other43", lod=500 },
		{ model=4606, model_file="other40", txd_file="main", coll_file="other40", lod=500 },
		{ model=4607, model_file="other38", txd_file="main", coll_file="other38", lod=500 },
		{ model=4608, model_file="other37", txd_file="main", coll_file="other37", lod=500 },
		{ model=4609, model_file="other34", txd_file="main", coll_file="other34", lod=500 },
		{ model=4610, model_file="other33", txd_file="main", coll_file="other33", lod=500 },
		{ model=4611, model_file="other32", txd_file="main", coll_file="other32", lod=500 },
		{ model=4612, model_file="other31", txd_file="main", coll_file="other31", lod=500 },
		{ model=4613, model_file="other30", txd_file="main", coll_file="other30", lod=500 },
		{ model=4614, model_file="other29", txd_file="main", coll_file="other29", lod=500 },
		{ model=4615, model_file="other28", txd_file="main", coll_file="other28", lod=500 },
		{ model=4616, model_file="other27", txd_file="main", coll_file="other27", lod=500 },
		{ model=4617, model_file="other26", txd_file="main", coll_file="other26", lod=500 },
		{ model=4618, model_file="other25", txd_file="main", coll_file="other25", lod=500 },
		{ model=4619, model_file="other24", txd_file="main", coll_file="other24", lod=500 },
		{ model=4620, model_file="other23", txd_file="main", coll_file="other23", lod=500 },
		{ model=4621, model_file="other22", txd_file="main", coll_file="other22", lod=500 },
		{ model=4622, model_file="other21", txd_file="main", coll_file="other21", lod=500 },
		{ model=4623, model_file="other20", txd_file="main", coll_file="other20", lod=500 },
		{ model=4624, model_file="other19", txd_file="main", coll_file="other19", lod=500 },
		{ model=4625, model_file="other18", txd_file="main", coll_file="other18", lod=500 },
		{ model=4626, model_file="other17", txd_file="main", coll_file="other17", lod=500 },
		{ model=4627, model_file="other16", txd_file="main", coll_file="other16", lod=500 },
		{ model=4628, model_file="other15", txd_file="main", coll_file="other15", lod=500 },
		{ model=4629, model_file="other14", txd_file="main", coll_file="other14", lod=500 },
		{ model=4630, model_file="other13", txd_file="main", coll_file="other13", lod=500 },
		{ model=4631, model_file="other12", txd_file="main", coll_file="other12", lod=500 },
		{ model=4632, model_file="other11", txd_file="main", coll_file="other11", lod=500 },
		{ model=4633, model_file="other10", txd_file="main", coll_file="other10", lod=500 },
		{ model=4634, model_file="other09", txd_file="main", coll_file="other09", lod=500 },
		{ model=4635, model_file="other08", txd_file="main", coll_file="other08", lod=500 },
		{ model=4638, model_file="other07", txd_file="main", coll_file="other07", lod=500 },
		{ model=4639, model_file="other06", txd_file="main", coll_file="other06", lod=500 },
		{ model=4640, model_file="other05", txd_file="main", coll_file="other05", lod=500 },
		{ model=4641, model_file="other04", txd_file="main", coll_file="other04", lod=500 },
		{ model=4642, model_file="other03", txd_file="main", coll_file="other03", lod=500 },
		{ model=4643, model_file="other02", txd_file="main", coll_file="other02", lod=500 },
		{ model=4644, model_file="other01", txd_file="main", coll_file="other01", lod=500 },
		{ model=4645, model_file="Map229", txd_file="main", coll_file="Map229", lod=500 },
		{ model=4646, model_file="Map228", txd_file="main", coll_file="Map228", lod=500 },
		{ model=4647, model_file="Map227", txd_file="main", coll_file="Map227", lod=500 },
		{ model=4648, model_file="Map226", txd_file="main", coll_file="Map226", lod=500 },
		{ model=4649, model_file="Map225", txd_file="main", coll_file="Map225", lod=500 },
		{ model=4650, model_file="Map224", txd_file="main", coll_file="Map224", lod=500 },
		{ model=4651, model_file="Map223", txd_file="main", coll_file="Map223", lod=500 },
		{ model=4652, model_file="Map222", txd_file="main", coll_file="Map222", lod=500 },
		{ model=4654, model_file="Map221", txd_file="main", coll_file="Map221", lod=500 },
		{ model=4655, model_file="Map220", txd_file="main", coll_file="Map220", lod=500 },
		{ model=4656, model_file="Map219", txd_file="main", coll_file="Map219", lod=500 },
		{ model=4657, model_file="Map218", txd_file="main", coll_file="Map218", lod=500 },
		{ model=4658, model_file="Map217", txd_file="main", coll_file="Map217", lod=500 },
		{ model=4659, model_file="Map216", txd_file="main", coll_file="Map216", lod=500 },
		{ model=4660, model_file="Map215", txd_file="main", coll_file="Map215", lod=500 },
		{ model=4661, model_file="Map214", txd_file="main", coll_file="Map214", lod=500 },
		{ model=4662, model_file="Map213", txd_file="main", coll_file="Map213", lod=500 },
		{ model=4663, model_file="Map212", txd_file="main", coll_file="Map212", lod=500 },
		{ model=4665, model_file="Map211", txd_file="main", coll_file="Map211", lod=500 },
		{ model=4667, model_file="Map210", txd_file="main", coll_file="Map210", lod=500 },
		{ model=4668, model_file="Map209", txd_file="main", coll_file="Map209", lod=500 },
		{ model=4669, model_file="Map208", txd_file="main", coll_file="Map208", lod=500 },
		{ model=4670, model_file="Map207", txd_file="main", coll_file="Map207", lod=500 },
		{ model=4671, model_file="Map206", txd_file="main", coll_file="Map206", lod=500 },
		{ model=4672, model_file="Map205", txd_file="main", coll_file="Map205", lod=500 },
		{ model=4673, model_file="Map204", txd_file="main", coll_file="Map204", lod=500 },
		{ model=4674, model_file="Map203", txd_file="main", coll_file="Map203", lod=500 },
		{ model=4675, model_file="Map202", txd_file="main", coll_file="Map202", lod=500 },
		{ model=4676, model_file="Map201", txd_file="main", coll_file="Map201", lod=500 },
		{ model=4677, model_file="Map200", txd_file="main", coll_file="Map200", lod=500 },
		{ model=4678, model_file="Map199", txd_file="main", coll_file="Map199", lod=500 },
		{ model=4679, model_file="Map198", txd_file="main", coll_file="Map198", lod=500 },
		{ model=4680, model_file="Map197", txd_file="main", coll_file="Map197", lod=500 },
		{ model=4681, model_file="Map196", txd_file="main", coll_file="Map196", lod=500 },
		{ model=4682, model_file="Map195", txd_file="main", coll_file="Map195", lod=500 },
		{ model=4683, model_file="Map194", txd_file="main", coll_file="Map194", lod=500 },
		{ model=4684, model_file="Map193", txd_file="main", coll_file="Map193", lod=500 },
		{ model=4685, model_file="Map192", txd_file="main", coll_file="Map192", lod=500 },
		{ model=4686, model_file="Map191", txd_file="main", coll_file="Map191", lod=500 },
		{ model=4687, model_file="Map190", txd_file="main", coll_file="Map190", lod=500 },
		{ model=4688, model_file="Map189", txd_file="main", coll_file="Map189", lod=500 },
		{ model=4689, model_file="Map188", txd_file="main", coll_file="Map188", lod=500 },
		{ model=4690, model_file="Map187", txd_file="main", coll_file="Map187", lod=500 },
		{ model=4692, model_file="Map186", txd_file="main", coll_file="Map186", lod=500 },
		{ model=4693, model_file="Map185", txd_file="main", coll_file="Map185", lod=500 },
		{ model=4694, model_file="Map184", txd_file="main", coll_file="Map184", lod=500 },
		{ model=4695, model_file="Map183", txd_file="main", coll_file="Map183", lod=500 },
		{ model=4696, model_file="Map182", txd_file="main", coll_file="Map182", lod=500 },
		{ model=4697, model_file="Map181", txd_file="main", coll_file="Map181", lod=500 },
		{ model=4698, model_file="Map180", txd_file="main", coll_file="Map180", lod=500 },
		{ model=4699, model_file="Map179", txd_file="main", coll_file="Map179", lod=500 },
		{ model=4700, model_file="Map178", txd_file="main", coll_file="Map178", lod=500 },
		{ model=4701, model_file="Map177", txd_file="main", coll_file="Map177", lod=500 },
		{ model=4702, model_file="Map176", txd_file="main", coll_file="Map176", lod=500 },
		{ model=4703, model_file="Map175", txd_file="main", coll_file="Map175", lod=500 },
		{ model=4704, model_file="Map174", txd_file="main", coll_file="Map174", lod=500 },
		{ model=4705, model_file="Map173", txd_file="main", coll_file="Map173", lod=500 },
		{ model=4706, model_file="Map172", txd_file="main", coll_file="Map172", lod=500 },
		{ model=4707, model_file="Map171", txd_file="main", coll_file="Map171", lod=500 },
		{ model=4708, model_file="Map170", txd_file="main", coll_file="Map170", lod=500 },
		{ model=4709, model_file="Map169", txd_file="main", coll_file="Map169", lod=500 },
		{ model=4710, model_file="Map168", txd_file="main", coll_file="Map168", lod=500 },
		{ model=4712, model_file="Map167", txd_file="main", coll_file="Map167", lod=500 },
		{ model=4713, model_file="Map166", txd_file="main", coll_file="Map166", lod=500 },
		{ model=4718, model_file="Map165", txd_file="main", coll_file="Map165", lod=500 },
		{ model=4719, model_file="Map164", txd_file="main", coll_file="Map164", lod=500 },
		{ model=4720, model_file="Map163", txd_file="main", coll_file="Map163", lod=500 },
		{ model=4721, model_file="Map162", txd_file="main", coll_file="Map162", lod=500 },
		{ model=4722, model_file="Map161", txd_file="main", coll_file="Map161", lod=500 },
		{ model=4724, model_file="Map160", txd_file="main", coll_file="Map160", lod=500 },
		{ model=4726, model_file="Map159", txd_file="main", coll_file="Map159", lod=500 },
		{ model=4728, model_file="Map158", txd_file="main", coll_file="Map158", lod=500 },
		{ model=4729, model_file="Map157", txd_file="main", coll_file="Map157", lod=500 },
		{ model=4730, model_file="Map156", txd_file="main", coll_file="Map156", lod=500 },
		{ model=4731, model_file="Map155", txd_file="main", coll_file="Map155", lod=500 },
		{ model=4732, model_file="Map154", txd_file="main", coll_file="Map154", lod=500 },
		{ model=4733, model_file="Map153", txd_file="main", coll_file="Map153", lod=500 },
		{ model=4734, model_file="Map152", txd_file="main", coll_file="Map152", lod=500 },
		{ model=4736, model_file="Map151", txd_file="main", coll_file="Map151", lod=500 },
		{ model=4753, model_file="Map150", txd_file="main", coll_file="Map150", lod=500 },
		{ model=4754, model_file="Map149", txd_file="main", coll_file="Map149", lod=500 },
		{ model=4755, model_file="Map148", txd_file="main", coll_file="Map148", lod=500 },
		{ model=4756, model_file="Map147", txd_file="main", coll_file="Map147", lod=500 },
		{ model=4757, model_file="Map146", txd_file="main", coll_file="Map146", lod=500 },
		{ model=4758, model_file="Map145", txd_file="main", coll_file="Map145", lod=500 },
		{ model=4759, model_file="Map144", txd_file="main", coll_file="Map144", lod=500 },
		{ model=4760, model_file="Map143", txd_file="main", coll_file="Map143", lod=500 },
		{ model=4761, model_file="Map142", txd_file="main", coll_file="Map142", lod=500 },
		{ model=4806, model_file="Map141", txd_file="main", coll_file="Map141", lod=500 },
		{ model=4807, model_file="Map140", txd_file="main", coll_file="Map140", lod=500 },
		{ model=4808, model_file="Map139", txd_file="main", coll_file="Map139", lod=500 },
		{ model=4811, model_file="Map138", txd_file="main", coll_file="Map138", lod=500 },
		{ model=4812, model_file="Map137", txd_file="main", coll_file="Map137", lod=500 },
		{ model=4814, model_file="Map136", txd_file="main", coll_file="Map136", lod=500 },
		{ model=4815, model_file="Map135", txd_file="main", coll_file="Map135", lod=500 },
		{ model=4816, model_file="Map134", txd_file="main", coll_file="Map134", lod=500 },
		{ model=4817, model_file="Map133", txd_file="main", coll_file="Map133", lod=500 },
		{ model=4818, model_file="Map132", txd_file="main", coll_file="Map132", lod=500 },
		{ model=4819, model_file="Map131", txd_file="main", coll_file="Map131", lod=500 },
		{ model=4821, model_file="Map130", txd_file="main", coll_file="Map130", lod=500 },
		{ model=4823, model_file="Map129", txd_file="main", coll_file="Map129", lod=500 },
		{ model=4824, model_file="Map128", txd_file="main", coll_file="Map128", lod=500 },
		{ model=4825, model_file="Map127", txd_file="main", coll_file="Map127", lod=500 },
		{ model=4826, model_file="Map126", txd_file="main", coll_file="Map126", lod=500 },
		{ model=4830, model_file="Map125", txd_file="main", coll_file="Map125", lod=500 },
		{ model=4836, model_file="Map124", txd_file="main", coll_file="Map124", lod=500 },
		{ model=4837, model_file="Map123", txd_file="main", coll_file="Map123", lod=500 },
		{ model=4839, model_file="Map122", txd_file="main", coll_file="Map122", lod=500 },
		{ model=4850, model_file="Map121", txd_file="main", coll_file="Map121", lod=500 },
		{ model=4853, model_file="Map120", txd_file="main", coll_file="Map120", lod=500 },
		{ model=4857, model_file="Map119", txd_file="main", coll_file="Map119", lod=500 },
		{ model=4858, model_file="Map118", txd_file="main", coll_file="Map118", lod=500 },
		{ model=4859, model_file="Map117", txd_file="main", coll_file="Map117", lod=500 },
		{ model=4861, model_file="Map116", txd_file="main", coll_file="Map116", lod=500 },
		{ model=4864, model_file="Map115", txd_file="main", coll_file="Map115", lod=500 },
		{ model=4871, model_file="Map114", txd_file="main", coll_file="Map114", lod=500 },
		{ model=4873, model_file="Map113", txd_file="main", coll_file="Map113", lod=500 },
		{ model=4876, model_file="Map112", txd_file="main", coll_file="Map112", lod=500 },
		{ model=4877, model_file="Map111", txd_file="main", coll_file="Map111", lod=500 },
		{ model=4878, model_file="Map110", txd_file="main", coll_file="Map110", lod=500 },
		{ model=4880, model_file="Map109", txd_file="main", coll_file="Map109", lod=500 },
		{ model=4886, model_file="Map108", txd_file="main", coll_file="Map108", lod=500 },
		{ model=4887, model_file="Map107", txd_file="main", coll_file="Map107", lod=500 },
		{ model=4888, model_file="Map106", txd_file="main", coll_file="Map106", lod=500 },
		{ model=4889, model_file="Map105", txd_file="main", coll_file="Map105", lod=500 },
		{ model=4891, model_file="Map104", txd_file="main", coll_file="Map104", lod=500 },
		{ model=4892, model_file="Map103", txd_file="main", coll_file="Map103", lod=500 },
		{ model=4893, model_file="Map102", txd_file="main", coll_file="Map102", lod=500 },
		{ model=4894, model_file="Map101", txd_file="main", coll_file="Map101", lod=500 },
		{ model=4895, model_file="Map100", txd_file="main", coll_file="Map100", lod=500 },
		{ model=4896, model_file="Map99", txd_file="main", coll_file="Map99", lod=500 },
		{ model=4898, model_file="Map98", txd_file="main", coll_file="Map98", lod=500 },
		{ model=4899, model_file="Map97", txd_file="main", coll_file="Map97", lod=500 },
		{ model=4900, model_file="Map96", txd_file="main", coll_file="Map96", lod=500 },
		{ model=4901, model_file="Map95", txd_file="main", coll_file="Map95", lod=500 },
		{ model=4902, model_file="Map94", txd_file="main", coll_file="Map94", lod=500 },
		{ model=4903, model_file="Map93", txd_file="main", coll_file="Map93", lod=500 },
		{ model=4904, model_file="Map92", txd_file="main", coll_file="Map92", lod=500 },
		{ model=4905, model_file="Map91", txd_file="main", coll_file="Map91", lod=500 },
		{ model=4906, model_file="Map90", txd_file="main", coll_file="Map90", lod=500 },
		{ model=4907, model_file="Map89", txd_file="main", coll_file="Map89", lod=500 },
		{ model=4908, model_file="Map88", txd_file="main", coll_file="Map88", lod=500 },
		{ model=4909, model_file="Map87", txd_file="main", coll_file="Map87", lod=500 },
		{ model=4910, model_file="Map86", txd_file="main", coll_file="Map86", lod=500 },
		{ model=4911, model_file="Map85", txd_file="main", coll_file="Map85", lod=500 },
		{ model=4912, model_file="Map84", txd_file="main", coll_file="Map84", lod=500 },
		{ model=4913, model_file="Map83", txd_file="main", coll_file="Map83", lod=500 },
		{ model=4914, model_file="Map82", txd_file="main", coll_file="Map82", lod=500 },
		{ model=4915, model_file="Map81", txd_file="main", coll_file="Map81", lod=500 },
		{ model=4916, model_file="Map80", txd_file="main", coll_file="Map80", lod=500 },
		{ model=4917, model_file="Map79", txd_file="main", coll_file="Map79", lod=500 },
		{ model=4918, model_file="Map78", txd_file="main", coll_file="Map78", lod=500 },
		{ model=4919, model_file="Map77", txd_file="main", coll_file="Map77", lod=500 },
		{ model=4920, model_file="Map76", txd_file="main", coll_file="Map76", lod=500 },
		{ model=4921, model_file="Map75", txd_file="main", coll_file="Map75", lod=500 },
		{ model=4922, model_file="Map74", txd_file="main", coll_file="Map74", lod=500 },
		{ model=4923, model_file="Map73", txd_file="main", coll_file="Map73", lod=500 },
		{ model=4924, model_file="Map72", txd_file="main", coll_file="Map72", lod=500 },
		{ model=4925, model_file="Map71", txd_file="main", coll_file="Map71", lod=500 },
		{ model=4926, model_file="Map70", txd_file="main", coll_file="Map70", lod=500 },
		{ model=4927, model_file="Map69", txd_file="main", coll_file="Map69", lod=500 },
		{ model=4928, model_file="Map68", txd_file="main", coll_file="Map68", lod=500 },
		{ model=4929, model_file="Map67", txd_file="main", coll_file="Map67", lod=500 },
		{ model=4930, model_file="Map66", txd_file="main", coll_file="Map66", lod=500 },
		{ model=4931, model_file="Map65", txd_file="main", coll_file="Map65", lod=500 },
		{ model=4932, model_file="Map64", txd_file="main", coll_file="Map64", lod=500 },
		{ model=4933, model_file="Map63", txd_file="main", coll_file="Map63", lod=500 },
		{ model=4934, model_file="Map62", txd_file="main", coll_file="Map62", lod=500 },
		{ model=4935, model_file="Map61", txd_file="main", coll_file="Map61", lod=500 },
		{ model=4936, model_file="Map60", txd_file="main", coll_file="Map60", lod=500 },
		{ model=4937, model_file="Map59", txd_file="main", coll_file="Map59", lod=500 },
		{ model=4938, model_file="Map58", txd_file="main", coll_file="Map58", lod=500 },
		{ model=4939, model_file="Map57", txd_file="main", coll_file="Map57", lod=500 },
		{ model=4940, model_file="Map56", txd_file="main", coll_file="Map56", lod=500 },
		{ model=4941, model_file="Map55", txd_file="main", coll_file="Map55", lod=500 },
		{ model=4942, model_file="Map54", txd_file="main", coll_file="Map54", lod=500 },
		{ model=4943, model_file="Map53", txd_file="main", coll_file="Map53", lod=500 },
		{ model=4944, model_file="Map52", txd_file="main", coll_file="Map52", lod=500 },
		{ model=4945, model_file="Map51", txd_file="main", coll_file="Map51", lod=500 },
		{ model=4946, model_file="Map50", txd_file="main", coll_file="Map50", lod=500 },
		{ model=4947, model_file="Map49", txd_file="main", coll_file="Map49", lod=500 },
		{ model=4948, model_file="Map48", txd_file="main", coll_file="Map48", lod=500 },
		{ model=4949, model_file="Map47", txd_file="main", coll_file="Map47", lod=500 },
		{ model=4950, model_file="Map46", txd_file="main", coll_file="Map46", lod=500 },
		{ model=4951, model_file="Map45", txd_file="main", coll_file="Map45", lod=500 },
		{ model=4952, model_file="Map44", txd_file="main", coll_file="Map44", lod=500 },
		{ model=4953, model_file="Map43", txd_file="main", coll_file="Map43", lod=500 },
		{ model=4954, model_file="Map42", txd_file="main", coll_file="Map42", lod=500 },
		{ model=4955, model_file="Map41", txd_file="main", coll_file="Map41", lod=500 },
		{ model=4956, model_file="Map40", txd_file="main", coll_file="Map40", lod=500 },
		{ model=4957, model_file="Map39", txd_file="main", coll_file="Map39", lod=500 },
		{ model=4958, model_file="Map38", txd_file="main", coll_file="Map38", lod=500 },
		{ model=4959, model_file="Map37", txd_file="main", coll_file="Map37", lod=500 },
		{ model=4960, model_file="Map36", txd_file="main", coll_file="Map36", lod=500 },
		{ model=4961, model_file="Map35", txd_file="main", coll_file="Map35", lod=500 },
		{ model=4962, model_file="Map34", txd_file="main", coll_file="Map34", lod=500 },
		{ model=4963, model_file="Map33", txd_file="main", coll_file="Map33", lod=500 },
		{ model=4964, model_file="Map32", txd_file="main", coll_file="Map32", lod=500 },
		{ model=4965, model_file="Map31", txd_file="main", coll_file="Map31", lod=500 },
		{ model=4966, model_file="Map30", txd_file="main", coll_file="Map30", lod=500 },
		{ model=4967, model_file="Map29", txd_file="main", coll_file="Map29", lod=500 },
		{ model=4968, model_file="Map28", txd_file="main", coll_file="Map28", lod=500 },
		{ model=4969, model_file="Map27", txd_file="main", coll_file="Map27", lod=500 },
		{ model=4970, model_file="Map26", txd_file="main", coll_file="Map26", lod=500 },
		{ model=4971, model_file="Map25", txd_file="main", coll_file="Map25", lod=500 },
		{ model=4972, model_file="Map24", txd_file="main", coll_file="Map24", lod=500 },
		{ model=4973, model_file="Map23", txd_file="main", coll_file="Map23", lod=500 },
		{ model=4974, model_file="Map22", txd_file="main", coll_file="Map22", lod=500 },
		{ model=4975, model_file="Map21", txd_file="main", coll_file="Map21", lod=500 },
		{ model=4976, model_file="Map20", txd_file="main", coll_file="Map20", lod=500 },
		{ model=4977, model_file="Map19", txd_file="main", coll_file="Map19", lod=500 },
		{ model=4978, model_file="Map18", txd_file="main", coll_file="Map18", lod=500 },
		{ model=4979, model_file="Map17", txd_file="main", coll_file="Map17", lod=500 },
		{ model=4980, model_file="Map16", txd_file="main", coll_file="Map16", lod=500 },
		{ model=4987, model_file="Map15", txd_file="main", coll_file="Map15", lod=500 },
		{ model=4988, model_file="Map14", txd_file="main", coll_file="Map14", lod=500 },
		{ model=4989, model_file="Map13", txd_file="main", coll_file="Map13", lod=500 },
		{ model=5006, model_file="Map12", txd_file="main", coll_file="Map12", lod=500 },
		{ model=5008, model_file="Map11", txd_file="main", coll_file="Map11", lod=500 },
		{ model=5010, model_file="Map10", txd_file="main", coll_file="Map10", lod=500 },
		{ model=5011, model_file="Map09", txd_file="main", coll_file="Map09", lod=500 },
		{ model=5012, model_file="Map08", txd_file="main", coll_file="Map08", lod=500 },
		{ model=5013, model_file="Map07", txd_file="main", coll_file="Map07", lod=500 },
		{ model=5014, model_file="Map06", txd_file="main", coll_file="Map06", lod=500 },
		{ model=5015, model_file="Map05", txd_file="main", coll_file="Map05", lod=500 },
		{ model=5016, model_file="Map04", txd_file="main", coll_file="Map04", lod=500 },
		{ model=5017, model_file="Map03", txd_file="main", coll_file="Map03", lod=500 },
		{ model=5018, model_file="Map02", txd_file="main", coll_file="Map02", lod=500 },
		{ model=5019, model_file="Map01", txd_file="main", coll_file="Map01", lod=500 },
		{ model=5026, model_file="Road02", txd_file="main", coll_file="Road02", lod=500 },
		{ model=5027, model_file="Road03", txd_file="main", coll_file="Road03", lod=500 },
		{ model=5029, model_file="Road04", txd_file="main", coll_file="Road04", lod=500 },
		{ model=5032, model_file="Road05", txd_file="main", coll_file="Road05", lod=500 },
		{ model=5035, model_file="Road06", txd_file="main", coll_file="Road06", lod=500 },
		{ model=5036, model_file="Road07", txd_file="main", coll_file="Road07", lod=500 },
		{ model=5037, model_file="Road08", txd_file="main", coll_file="Road08", lod=500 },
		{ model=5039, model_file="Road09", txd_file="main", coll_file="Road09", lod=500 },
		{ model=5040, model_file="Road10", txd_file="main", coll_file="Road10", lod=500 },
		{ model=5041, model_file="Road11", txd_file="main", coll_file="Road11", lod=500 },
		{ model=5042, model_file="Road12", txd_file="main", coll_file="Road12", lod=500 },
		{ model=5044, model_file="Road13", txd_file="main", coll_file="Road13", lod=500 },
		{ model=5045, model_file="Road14", txd_file="main", coll_file="Road14", lod=500 },
		{ model=5047, model_file="Road15", txd_file="main", coll_file="Road15", lod=500 },
		{ model=5048, model_file="Road16", txd_file="main", coll_file="Road16", lod=500 },
		{ model=5049, model_file="Road17", txd_file="main", coll_file="Road17", lod=500 },
		{ model=5050, model_file="Road18", txd_file="main", coll_file="Road18", lod=500 },
		{ model=5051, model_file="Road19", txd_file="main", coll_file="Road19", lod=500 },
		{ model=5053, model_file="Road20", txd_file="main", coll_file="Road20", lod=500 },
		{ model=5054, model_file="Road21", txd_file="main", coll_file="Road21", lod=500 },
		{ model=5055, model_file="Road22", txd_file="main", coll_file="Road22", lod=500 },
		{ model=5060, model_file="Road23", txd_file="main", coll_file="Road23", lod=500 },
		{ model=5063, model_file="Road24", txd_file="main", coll_file="Road24", lod=500 },
		{ model=5064, model_file="Road25", txd_file="main", coll_file="Road25", lod=500 },
		{ model=5065, model_file="Road26", txd_file="main", coll_file="Road26", lod=500 },
		{ model=5066, model_file="Road27", txd_file="main", coll_file="Road27", lod=500 },
		{ model=5067, model_file="Road28", txd_file="main", coll_file="Road28", lod=500 },
		{ model=5068, model_file="Road29", txd_file="main", coll_file="Road29", lod=500 },
		{ model=5071, model_file="Road30", txd_file="main", coll_file="Road30", lod=500 },
		{ model=5072, model_file="Road31", txd_file="main", coll_file="Road31", lod=500 },
		{ model=5073, model_file="Road32", txd_file="main", coll_file="Road32", lod=500 },
		{ model=5110, model_file="Road33", txd_file="main", coll_file="Road33", lod=500 },
		{ model=5111, model_file="Road34", txd_file="main", coll_file="Road34", lod=500 },
		{ model=5113, model_file="Road35", txd_file="main", coll_file="Road35", lod=500 },
		{ model=5114, model_file="Road36", txd_file="main", coll_file="Road36", lod=500 },
		{ model=5116, model_file="Road37", txd_file="main", coll_file="Road37", lod=500 },
		{ model=5121, model_file="Road38", txd_file="main", coll_file="Road38", lod=500 },
		{ model=5122, model_file="Road39", txd_file="main", coll_file="Road39", lod=500 },
		{ model=5124, model_file="Road40", txd_file="main", coll_file="Road40", lod=500 },
		{ model=5126, model_file="Road41", txd_file="main", coll_file="Road41", lod=500 },
		{ model=5127, model_file="Road42", txd_file="main", coll_file="Road42", lod=500 },
		{ model=5128, model_file="Road43", txd_file="main", coll_file="Road43", lod=500 },
		{ model=5130, model_file="Road44", txd_file="main", coll_file="Road44", lod=500 },
		{ model=5131, model_file="Road45", txd_file="main", coll_file="Road45", lod=500 },
		{ model=5132, model_file="Road46", txd_file="main", coll_file="Road46", lod=500 },
		{ model=5133, model_file="Road47", txd_file="main", coll_file="Road47", lod=500 },
		{ model=5135, model_file="Road48", txd_file="main", coll_file="Road48", lod=500 },
		{ model=5136, model_file="Road49", txd_file="main", coll_file="Road49", lod=500 },
		{ model=5139, model_file="Road50", txd_file="main", coll_file="Road50", lod=500 },
		{ model=5140, model_file="Road51", txd_file="main", coll_file="Road51", lod=500 },
		{ model=5141, model_file="Road52", txd_file="main", coll_file="Road52", lod=500 },
		{ model=5142, model_file="Road53", txd_file="main", coll_file="Road53", lod=500 },
		{ model=5144, model_file="Road54", txd_file="main", coll_file="Road54", lod=500 },
		{ model=5149, model_file="Road55", txd_file="main", coll_file="Road55", lod=500 },
		{ model=5152, model_file="Road56", txd_file="main", coll_file="Road56", lod=500 },
		{ model=5153, model_file="Road57", txd_file="main", coll_file="Road57", lod=500 },
		{ model=5154, model_file="Road58", txd_file="main", coll_file="Road58", lod=500 },
		{ model=5155, model_file="Road59", txd_file="main", coll_file="Road59", lod=500 },
		{ model=5157, model_file="Road60", txd_file="main", coll_file="Road60", lod=500 },
		{ model=5158, model_file="Road61", txd_file="main", coll_file="Road61", lod=500 },
		{ model=5159, model_file="Road62", txd_file="main", coll_file="Road62", lod=500 },
		{ model=5161, model_file="Road63", txd_file="main", coll_file="Road63", lod=500 },
		{ model=5162, model_file="Road64", txd_file="main", coll_file="Road64", lod=500 },
		{ model=5163, model_file="Road65", txd_file="main", coll_file="Road65", lod=500 },
		{ model=5164, model_file="Road66", txd_file="main", coll_file="Road66", lod=500 },
		{ model=5165, model_file="Road67", txd_file="main", coll_file="Road67", lod=500 },
		{ model=5168, model_file="Road68", txd_file="main", coll_file="Road68", lod=500 },
		{ model=5170, model_file="Road69", txd_file="main", coll_file="Road69", lod=500 },
		{ model=5171, model_file="Road70", txd_file="main", coll_file="Road70", lod=500 },
		{ model=5172, model_file="Road71", txd_file="main", coll_file="Road71", lod=500 },
		{ model=5173, model_file="Road72", txd_file="main", coll_file="Road72", lod=500 },
		{ model=5174, model_file="Road73", txd_file="main", coll_file="Road73", lod=500 },
		{ model=5175, model_file="Road74", txd_file="main", coll_file="Road74", lod=500 },
		{ model=5177, model_file="Road75", txd_file="main", coll_file="Road75", lod=500 },
		{ model=5178, model_file="Road76", txd_file="main", coll_file="Road76", lod=500 },
		{ model=5179, model_file="Road77", txd_file="main", coll_file="Road77", lod=500 },
		{ model=5180, model_file="Road78", txd_file="main", coll_file="Road78", lod=500 },
		{ model=5181, model_file="Road79", txd_file="main", coll_file="Road79", lod=500 },
		{ model=5182, model_file="Road80", txd_file="main", coll_file="Road80", lod=500 },
		{ model=5183, model_file="Road81", txd_file="main", coll_file="Road81", lod=500 },
		{ model=5184, model_file="Road82", txd_file="main", coll_file="Road82", lod=500 },
		{ model=5185, model_file="Road83", txd_file="main", coll_file="Road83", lod=500 },
		{ model=5186, model_file="Road84", txd_file="main", coll_file="Road84", lod=500 },
		{ model=5187, model_file="Road85", txd_file="main", coll_file="Road85", lod=500 },
		{ model=5189, model_file="Road86", txd_file="main", coll_file="Road86", lod=500 },
		{ model=5191, model_file="Road87", txd_file="main", coll_file="Road87", lod=500 },
		{ model=5192, model_file="Road88", txd_file="main", coll_file="Road88", lod=500 },
		{ model=5193, model_file="Road89", txd_file="main", coll_file="Road89", lod=500 },
		{ model=5194, model_file="Road90", txd_file="main", coll_file="Road90", lod=500 },
		{ model=5195, model_file="Road91", txd_file="main", coll_file="Road91", lod=500 },
		{ model=5196, model_file="Road92", txd_file="main", coll_file="Road92", lod=500 },
		{ model=5197, model_file="Road93", txd_file="main", coll_file="Road93", lod=500 },
		{ model=5198, model_file="Road94", txd_file="main", coll_file="Road94", lod=500 },
		{ model=5199, model_file="Road95", txd_file="main", coll_file="Road95", lod=500 },
		{ model=5200, model_file="Road96", txd_file="main", coll_file="Road96", lod=500 },
		{ model=5201, model_file="Road97", txd_file="main", coll_file="Road97", lod=500 },
		{ model=5202, model_file="Road98", txd_file="main", coll_file="Road98", lod=500 },
		{ model=5203, model_file="Road99", txd_file="main", coll_file="Road99", lod=500 },
		{ model=5204, model_file="Road100", txd_file="main", coll_file="Road100", lod=500 },
		{ model=5205, model_file="Road101", txd_file="main", coll_file="Road101", lod=500 },
		{ model=5206, model_file="Road102", txd_file="main", coll_file="Road102", lod=500 },
		{ model=5207, model_file="Road103", txd_file="main", coll_file="Road103", lod=500 },
		{ model=5208, model_file="Road104", txd_file="main", coll_file="Road104", lod=500 },
		{ model=5209, model_file="Road105", txd_file="main", coll_file="Road105", lod=500 },
		{ model=5210, model_file="Road106", txd_file="main", coll_file="Road106", lod=500 },
		{ model=5211, model_file="build52", txd_file="main", coll_file="build52", lod=500 },
		{ model=5212, model_file="build51", txd_file="main", coll_file="build51", lod=500 },
		{ model=5213, model_file="build50", txd_file="main", coll_file="build50", lod=500 },
		{ model=5214, model_file="build49", txd_file="main", coll_file="build49", lod=500 },
		{ model=5215, model_file="build48", txd_file="main", coll_file="build48", lod=500 },
		{ model=5216, model_file="build47", txd_file="main", coll_file="build47", lod=500 },
		{ model=5217, model_file="build46", txd_file="main", coll_file="build46", lod=500 },
		{ model=5218, model_file="build45", txd_file="main", coll_file="build45", lod=500 },
		{ model=5219, model_file="build44", txd_file="main", coll_file="build44", lod=500 },
		{ model=5220, model_file="build43", txd_file="main", coll_file="build43", lod=500 },
		{ model=5221, model_file="build42", txd_file="main", coll_file="build42", lod=500 },
		{ model=5222, model_file="build41", txd_file="main", coll_file="build41", lod=500 },
		{ model=5223, model_file="build40", txd_file="main", coll_file="build40", lod=500 },
		{ model=5224, model_file="build39", txd_file="main", coll_file="build39", lod=500 },
		{ model=5225, model_file="build38", txd_file="main", coll_file="build38", lod=500 },
		{ model=5226, model_file="build37", txd_file="main", coll_file="build37", lod=500 },
		{ model=5227, model_file="build36", txd_file="main", coll_file="build36", lod=500 },
		{ model=5228, model_file="build35", txd_file="main", coll_file="build35", lod=500 },
		{ model=5229, model_file="build34", txd_file="main", coll_file="build34", lod=500 },
		{ model=5230, model_file="build33", txd_file="main", coll_file="build33", lod=500 },
		{ model=5235, model_file="build32", txd_file="main", coll_file="build32", lod=500 },
		{ model=5236, model_file="build31", txd_file="main", coll_file="build31", lod=500 },
		{ model=5237, model_file="build439", txd_file="main", coll_file="build439", lod=500 },
		{ model=5238, model_file="build30", txd_file="main", coll_file="build30", lod=500 },
		{ model=5239, model_file="build29", txd_file="main", coll_file="build29", lod=500 },
		{ model=5240, model_file="build28", txd_file="main", coll_file="build28", lod=500 },
		{ model=5241, model_file="build27", txd_file="main", coll_file="build27", lod=500 },
		{ model=5242, model_file="build26", txd_file="main", coll_file="build26", lod=500 },
		{ model=5243, model_file="build25", txd_file="main", coll_file="build25", lod=500 },
		{ model=5244, model_file="build24", txd_file="main", coll_file="build24", lod=500 },
		{ model=5245, model_file="build23", txd_file="main", coll_file="build23", lod=500 },
		{ model=5246, model_file="build22", txd_file="main", coll_file="build22", lod=500 },
		{ model=5247, model_file="Map230", txd_file="main", coll_file="Map230", lod=500 },
		{ model=5248, model_file="build21", txd_file="main", coll_file="build21", lod=500 },
		{ model=5249, model_file="build20", txd_file="main", coll_file="build20", lod=500 },
		{ model=5251, model_file="build19", txd_file="main", coll_file="build19", lod=500 },
		{ model=5252, model_file="build18", txd_file="main", coll_file="build18", lod=500 },
		{ model=5253, model_file="build17", txd_file="main", coll_file="build17", lod=500 },
		{ model=5254, model_file="build16", txd_file="main", coll_file="build16", lod=500 },
		{ model=5255, model_file="other53", txd_file="main", coll_file="other53", lod=500 },
		{ model=5256, model_file="other51", txd_file="main", coll_file="other51", lod=500 },
		{ model=5257, model_file="other48", txd_file="main", coll_file="other48", lod=500 },
		{ model=5258, model_file="other46", txd_file="main", coll_file="other46", lod=500 },
		{ model=5259, model_file="other44", txd_file="main", coll_file="other44", lod=500 },
		{ model=5260, model_file="other42", txd_file="main", coll_file="other42", lod=500 },
		{ model=5261, model_file="other41", txd_file="main", coll_file="other41", lod=500 },
		{ model=5262, model_file="other39", txd_file="main", coll_file="other39", lod=500 },
		{ model=5263, model_file="other36", txd_file="main", coll_file="other36", lod=500 },
		{ model=5264, model_file="other35", txd_file="main", coll_file="other35", lod=500 }
	};

	local n,m;

	for n,m in ipairs(pTable) do
		pModels[m.model] = {
			id = m.model,
			name = m.model_file,
			txd = requestTexture(false, "textures/"..m.txd_file..".txd"),
			numStream = 0,
			lod = m.lod,
			lodID = m.lodID
		};
		pModelEntry = pModels[m.model];
       if (pModelEntry.txd) then
		    engineImportTXD(pModelEntry.txd, m.model);
       end
		pModelEntry.model=engineLoadDFF("models/"..m.model_file..".dff", m.model);
		pModelEntry.col=engineLoadCOL("coll/"..m.coll_file..".col");
		engineSetModelLODDistance(m.model, m.lod);

		if (m.lodID) then
			for j,k in ipairs(getElementsByType("object", resourceRoot)) do
				if (getElementModel(k) == m.model) then
					local x, y, z = getElementPosition(k);
					local rx, ry, rz = getElementRotation(k);
					setLowLODElement(k, createObject(m.lodID, x, y, z, rx, ry, rz, true));
				end
			end
		end
	end

	for m,n in pairs(pModels) do
		if (n.super) and not (n.col) then
           local superModel = pModels[n.super];
           if (superModel) then
			    n.col = superModel.col;
           end
		end
	end
end
loadModels();

for m,n in ipairs(getElementsByType("object", resourceRoot)) do
	if (isElementStreamedIn(n)) then
		source = n;
		modelStreamIn();
	end
end

addEventHandler("onClientElementStreamIn", resourceRoot, function()
		modelStreamIn();
	end
);
addEventHandler("onClientElementStreamOut", resourceRoot, function()
		modelStreamOut();
	end
);

addEventHandler("onClientResourceStop", resourceRoot, function()
		for m,n in pairs(pModels) do
			if (isElement(n.col)) then destroyElement(n.col); end
			if (isElement(n.model)) then destroyElement(n.model); end
			engineRestoreCOL(m);
			engineRestoreModel(m);
		end
       for m,n in pairs(textureCache) do
           destroyElement(n);
       end
	end
);

collectgarbage("collect");
